@@ -483,7 +483,8 @@ piecewise <- function(mR, rData = NULL, options = list()) {
     if (op$online) {
       if (i > op$n) {
         lastchange <- max(which(cp + op$n < i))
-        lastchange = 1
+      } else {
+        lastchange <- 1
       }
       lastchange <- cp[lastchange]
       spot[i] = switch(op$volEst,
@@ -556,27 +557,6 @@ changePoints <- function(vR, type = "MDa", alpha = 0.005, m = 40, n = 20) {
   return(points)
 }
 
-#' # Difference of medians test
-#' # See Fried (2012)
-#' # Returns TRUE if H0 is rejected
-#' # importFrom stats density
-#' # keywords internal
-#' DMtest <- function(x, y, alpha = 0.005) {
-#'   m <- length(x)
-#'   n <- length(y)
-#'   xmed <- median(x)
-#'   ymed <- median(y)
-#'   xcor <- x - xmed
-#'   ycor <- y - ymed
-#'   delta1 <- ymed - xmed
-#'   out <- density(c(xcor, ycor), kernel = "epanechnikov")
-#'   fmed <- as.numeric(BMS::quantile.density(out, probs = 0.5))
-#'   fmedvalue <- (out$y[max(which(out$x < fmed))] +
-#'                   out$y[max(which(out$x < fmed))+1])/2
-#'   test <- sqrt((m*n)/(m + n))*2*fmedvalue*delta1
-#'   return(abs(test) > qnorm(1-alpha/2))
-#' }
-
 # Median difference test
 # See Fried (2012)
 # Returns TRUE if H0 is rejected
